# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ...core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ...core.serialization import FieldMetadata
from .data_filter import DataFilter
from .web_search_result import WebSearchResult


class InitialChunk(UniversalBaseModel):
    conversation_id: typing_extensions.Annotated[str, FieldMetadata(alias="conversationId")]
    warnings: typing.List[str]
    web_search_results: typing_extensions.Annotated[
        typing.List[WebSearchResult], FieldMetadata(alias="webSearchResults")
    ]
    data_filters: typing_extensions.Annotated[typing.Optional[DataFilter], FieldMetadata(alias="dataFilters")] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
